@@ -37,9 +37,10 @@ class GitCloneBuilder(object):
         base = f"git clone --depth {self._depth} --single-branch -q "
         if self._branch:
             base += f"--branch {self._branch} "
-        base += f"{self.repo} "
+        # Double quotes for Macs which allow spaces in dir names
+        base += f"\"{self.repo}\" "
         if self._path:
-            base += f"{self._path} "
+            base += f"\"{self._path}\" "
         return base
 
 
@@ -64,7 +65,9 @@ class ActionConfig(object):
         if self.name.lower().startswith("datatorch/"):
             self.name = self.name.lower().replace("datatorch/", "datatorch-actions/")
 
-        self.git = self.git or f"git://github.com/{self.name}.git"
+        # I took this out because git:// fails to connect if the port is blocked
+        #self.git = self.git or f"git://github.com/{self.name}.git"
+        self.git = self.git or f"https://github.com/{self.name}.git"
         self.depth: int = 1
 
     async def download(self):
