@@ -18,7 +18,11 @@ class PythonRunner(Runner):
 
     async def execute(self):
         main = self.get("main").strip("/")
-        main_command = os.path.join(self.action.dir, main)
+        # Ok this command parsing stuff is to handle Application Support folder in Macs
+        # Because there are spaces in the folder name
+        main_command_spaces = os.path.join(self.action.dir, main)
+        main_command_nospaces = main_command_spaces.replace(" ","\ ")
+
         json_input = json.dumps(self.variables.inputs).replace("'", '\\"')
 
-        await self.monitor_cmd(f"{sys.executable} {main_command} '{json_input}'")
+        await self.monitor_cmd(f"{sys.executable} {main_command_nospaces} '{json_input}'")
